CNGlassButtonGroup constructor
const
CNGlassButtonGroup({})
Creates a group of glass buttons using data models.
The buttons list contains button data models.
The axis determines whether buttons are laid out horizontally (Axis.horizontal)
or vertically (Axis.vertical).
The spacing controls the spacing between buttons in the layout (HStack/VStack).
The spacingForGlass controls how Liquid Glass effects blend together.
For proper blending, spacingForGlass should be larger than spacing so that
glass effects merge when buttons are close together.
Implementation
const CNGlassButtonGroup({
super.key,
required this.buttons,
this.axis = Axis.horizontal,
this.spacing = 8.0,
this.spacingForGlass = 40.0,
}) : _buttonWidgets = null;