isSearchTab property

bool isSearchTab
final

Whether this tab triggers the iOS 26 native search bar.

Only one tab should be marked as a search tab. When selected, the native search bar appears with the Liquid Glass morphing effect.

Implementation

final bool isSearchTab;