deactivateSearch static method

Future<void> deactivateSearch()

Dismisses the search bar and returns to the previously selected tab.

No-op when the native tab bar is not enabled.

Implementation

static Future<void> deactivateSearch() async {
  if (!_isEnabled) return;
  await _channel.invokeMethod('deactivateSearch');
}