setBadgeCounts static method
Updates badge counts for each tab.
Provide null for a tab to clear its badge.
The list length should match the number of tabs passed to enable.
No-op when the native tab bar is not enabled.
Implementation
static Future<void> setBadgeCounts(List<int?> badgeCounts) async {
if (!_isEnabled) return;
await _channel.invokeMethod('setBadgeCounts', {'badgeCounts': badgeCounts});
}