setBrightness static method

Future<void> setBrightness({
  1. required bool isDark,
})

Notifies the native tab bar of a light/dark mode change.

Call this when MediaQuery.platformBrightness changes if you have not enabled automatic brightness propagation. No-op when the native tab bar is not enabled.

Implementation

static Future<void> setBrightness({required bool isDark}) async {
  if (!_isEnabled) return;
  await _channel.invokeMethod('setBrightness', {'isDark': isDark});
}