setSearchText static method

Future<void> setSearchText(
  1. String text
)

Sets the search field text to text without triggering the keyboard.

No-op when the native tab bar is not enabled.

Implementation

static Future<void> setSearchText(String text) async {
  if (!_isEnabled) return;
  await _channel.invokeMethod('setSearchText', {'text': text});
}