CNPopupMenuItem class
A selectable item in a popup menu.
- Inheritance
-
- Object
- CNPopupMenuEntry
- CNPopupMenuItem
Constructors
Properties
- customIcon → IconData?
-
Optional custom icon from CupertinoIcons, Icons, or any IconData.
If provided, this takes precedence over icon but not imageAsset.
final
- enabled → bool
-
Whether the item can be selected.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → CNSymbol?
-
Optional SF Symbol shown before the label.
Priority: imageAsset > customIcon > icon
final
- iconColor → Color?
-
Optional color for custom icons. This applies a tint color to the custom icon.
For SF Symbols, use the icon's color parameter instead.
final
- imageAsset → CNIcon?
-
Optional image asset (SVG, PNG, etc.) shown before the label.
If provided, this takes precedence over icon and customIcon.
final
- label → String
-
Display label for the item.
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited