CNToastDuration enum
Duration presets for toasts.
Values
- short → const CNToastDuration
-
Short duration (2 seconds).
- medium → const CNToastDuration
-
Medium duration (3.5 seconds).
- long → const CNToastDuration
-
Long duration (5 seconds).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CNToastDuration> - A constant List of the values in this enum, in order of their declaration.