CNButtonGlassMaterial enum

Glass material for button glass effects on iOS 26+.

Controls which Glass base material is used when rendering button glass effects.

Inheritance
Available extensions

Values

clear → const CNButtonGlassMaterial

Clear glass (default). Subtle, translucent button appearance.

regular → const CNButtonGlassMaterial

Regular glass. More opaque, standard glass appearance.

identity → const CNButtonGlassMaterial

Identity glass. Pass-through base material for custom-tinted or layered glass.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<CNButtonGlassMaterial>
A constant List of the values in this enum, in order of their declaration.