CNTabBarSearchController class

Controller for programmatically managing the search tab state.

Use this to:

  • Activate/deactivate search programmatically
  • Set or clear the search text
  • Listen to search state changes

Example:

final searchController = CNTabBarSearchController();

// Activate search programmatically
searchController.activateSearch();

// Set search text
searchController.text = 'query';

// Listen to changes
searchController.addListener(() {
  print('Search active: ${searchController.isActive}');
  print('Search text: ${searchController.text}');
});
Inheritance

Constructors

CNTabBarSearchController()

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
isActive bool
Whether the search bar is currently expanded/active.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
The current search text.
getter/setter pair

Methods

activateSearch() → void
Activates the search bar (expands it and shows keyboard).
addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
clear({bool deactivate = false}) → void
Clears the search text and optionally deactivates search.
deactivateSearch() → void
Deactivates the search bar (collapses it back to button).
dispose() → void
Discards any resources used by the object. After this is called, the object is not in a usable state and should be discarded (calls to addListener will throw after the object is disposed).
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited