readyNotifier property
Notifier that fires once when readiness flips to true.
Implementation
static final ValueNotifier<bool> readyNotifier = ValueNotifier<bool>(false);
Notifier that fires once when readiness flips to true.
static final ValueNotifier<bool> readyNotifier = ValueNotifier<bool>(false);