CNTab class
Configuration for a native tab in CNTabBarNative.
Each tab can have a title, SF Symbol icon, and optionally be marked as a search tab.
Example:
CNTab(
title: 'Home',
sfSymbol: CNSymbol('house.fill'),
)
Constructors
Properties
- activeSfSymbol → CNSymbol?
-
SF Symbol for the selected state.
final
- badgeCount → int?
-
Badge count shown on the tab. Pass
nullfor no badge.final - hashCode → int
-
The hash code for this object.
no setterinherited
- isSearchTab → bool
-
Whether this tab triggers the iOS 26 native search bar.
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sfSymbol → CNSymbol?
-
SF Symbol for the unselected state.
final
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - title → String
-
Title shown below the tab icon.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited