activateSearch static method
Navigates to the search tab and focuses the search field.
No-op when the native tab bar is not enabled.
Implementation
static Future<void> activateSearch() async {
if (!_isEnabled) return;
await _channel.invokeMethod('activateSearch');
}