CNSymbol class
Describes an SF Symbol to render natively.
Prefer CNIcon.symbol for new code.
Constructors
Properties
- color → Color?
-
Preferred icon color (for monochrome/hierarchical modes).
final
- gradient → bool?
-
Whether to enable the built-in gradient when available.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mode → CNSymbolRenderingMode?
-
Optional per-icon rendering mode.
final
- name → String
-
The SF Symbol name, e.g.
chevron.down.final -
paletteColors
→ List<
Color> ? -
Palette colors for multi-color/palette modes.
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → double
-
Desired point size for the symbol.
final
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited